# XTA-Adapter
Der XTA-Adapter empfängt Anträge von Online-Diensten via XTA-Nachrichtenbroker und erzeugt für diese Anträge neue Vorgänge im Vorgang-Manager.

Der XTA-Adapter läuft als cronjob und beendet sich, nachdem alle unterstützten Anträge vom XTA-Nachrichtenbroker (XTA-Server) abgeholt wurden.
Jeder Antrag erzeugt einen neuen Vorgang im Vorgang-Manager. (Der Mantelantrag ist eine Ausnahme und kann mehrere Vorgänge erzeugen.)


## Konfiguration vom Helm-Chart
Die Standardeinstellung ist, dass der Adapter alle 5 Minuten startet:
```yaml
xta:
  schedule: '*/5 * * * *'
```

Es sollten Xta-Kennungen konfiguriert werden, für die Nachrichten abgeholt werden sollen, beispielsweise:
```yaml
identifiers:
  - gae:meinekennung1@ozg-cloud.de
  - vbe:123456789
```

Es wird ein `vorgang-manger` Service im Cluster angenommen:
```yaml
routing:
  targetVorgangManagerName: vorgang-manager
  fallbackStrategy: DENY
  routingStrategy: SINGLE
```

Die URL des XTA-Servers muss konfiguriert werden, beispielsweise:
```yaml
xta:
  server:
    name: xta-test-server
    address: xta-test-server-ozg4094.dev.by.ozg-cloud.de
    protocol: https
```

Der XTA-Adapter muss dem XTA-Server-Zertifikat vertrauen können.
Dafür muss ein Root-Zertifikat `xtaRootCa` (in Base64-Kodierung) konfiguriert werden:
```yaml
xta:
  rootCa: LS0tLS1CRUdJTiBDRVJUSUZ...
```

Der XTA-Adapter benötigt ein Client-Zertifikat, dass ihn zum Lesen der konfigurierten Xta-kennungen berechtigt.
Das Client-Zertifikat muss in einem P12-KeyStore (in Base64-Kodierung) abgelegt werden:
```yaml
xta:
  keystore:
    file: MIIFCwIBAzCCBMEG...
    password: password
```

## Verwendung mit dem xta-test-server

Der xta-test-server erlaubt mit einem validen Client-Zertifikat beliebige Nachricht-Typen mit beliebigen Kennungen zu senden und zu empfangen.
Das CA-Zertifikat und Client-Zertifikat sollte aus dem entsprechenden Secrets des xta-test-servers heruntergeladen werden.

Nähere Information hierzu sind in der internen-Dokumentation zu finden:
- https://git.ozg-sh.de/ozgcloud-doc/dokumentation/src/branch/master/Entwicklungsumgebung/Beistellungen/xta-test-server-SoapUI/README.md
- https://git.ozg-sh.de/ozgcloud-doc/dokumentation/src/branch/master/Entwicklungsumgebung#xta-adapter

## Verwendung mit dem Dataport-DEV-Nachrichtenbroker
Der Dataport-DEV-nachrichtenbroker ist nur erreichbar aus dem Landes-Netz.
Um das Root-CA-Zertifikat `Dataport Root CA` zu erhalten, welches als `rootCa` konfiguriert werden kann, kann die Zertifikat-Kette direkt vom Endpunkt angefragt werden:
```shell
openssl s_client -showcerts -connect li33-0005.dp.dsecurecloud.de:443 </dev/null
```

Für Ubuntu kann das Zertifikat im PEM Format in das Verzeichnis `/usr/local/share/ca-certificates/dataport-root-ca.crt`kopiert werden und anschlisend mit `sudo update-ca-certificates` dem Java Certstore hinzugefügt werden. (Es ist dabei wichtig das die Datei zum einen im PEM Format ist und zum anderen die Dateiendung `.crt` hat).

Das Client-Zertifikat `KOP_SH_KIEL_DEV.p12`, das den Xta-Adapter zum Lesen von Xta-Kennungen berechtigt, muss beantragt werden.
