/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xdomea;

import static de.ozgcloud.eingang.xdomea.XMLHelper.*;

import java.util.List;
import java.util.stream.IntStream;
import java.util.stream.Stream;

import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathExpressionException;

import org.springframework.stereotype.Component;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import de.ozgcloud.eingang.common.errorhandling.TechnicalException;
import de.ozgcloud.eingang.common.formdata.IncomingFile;

@Component
public class XdomeaXMLValueReader {

	private static final String DATEINAME_NODE_QUERY_STRING = "//Hauptobjekt//Dateiname";
	// Interpret XML-Attachments as representations
	// XML filetype code: 030 (see https://www.xrepository.de/details/urn:xoev-de:xdomea:codeliste:dateiformat)
	private static final String DATEINAME_NODE_FOR_XML_ANHANG_QUERY_STRING = "//Anlage//Format/Name[contains(., '030')]/..//Dateiname";
	private static final XPathExpression DATEINAME_NODE_QUERY = compileXPathExpression(
			DATEINAME_NODE_QUERY_STRING + "|" + DATEINAME_NODE_FOR_XML_ANHANG_QUERY_STRING);

	public List<String> readRepresentationFileNames(IncomingFile xdomeaXMLFile) {
		return getTextsFromNodes(
				queryDateinameNodeList(
						XMLHelper.parseDocument(xdomeaXMLFile)
								.getDocumentElement()
				)
		);
	}

	private NodeList queryDateinameNodeList(Element contextElement) {
		try {
			return (NodeList) DATEINAME_NODE_QUERY
					.evaluate(
							contextElement,
							XPathConstants.NODESET
					);
		} catch (XPathExpressionException e) {
			throw new TechnicalException("Failed to execute xpath search!", e);
		}
	}

	private List<String> getTextsFromNodes(NodeList nodeList) {
		return streamNodeList(nodeList)
				.map(Node::getTextContent)
				.map(String::trim)
				.toList();
	}

	private Stream<Node> streamNodeList(NodeList nodeList) {
		return IntStream.range(0, nodeList.getLength())
				.mapToObj(nodeList::item);
	}

}
