/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.StringUtils;

import java.time.ZonedDateTime;

import de.ozgcloud.xta.client.model.XtaMessageMetaData;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class XtaMapperHelper {

    public static String getFormEngineName(XtaMessageMetaData metaData) {
        if (StringUtils.equals(metaData.messageTypeCode(), XtaService.XDOMEA_0201_MESSAGE_TYPE)) {
            return "XDOMEA";
        }

        if (StringUtils.startsWith(metaData.messageTypeCode(), XtaService.FIM_MESSAGE_TYPE_PREFIX)) {
            return "FIM";
        }
        return null;
    }

    public static ZonedDateTime getCreatedAt(de.ozgcloud.xta.client.model.XtaMessageMetaData metaData) {
        if (metaData.deliveryAttributesOrigin() != null) {
            return metaData.deliveryAttributesOrigin();
        }
        return ZonedDateTime.now();
    }

}
