/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import java.util.Optional;

import org.mapstruct.Context;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.formdata.FormHeader;
import de.ozgcloud.eingang.common.formdata.FormMetaData;
import de.ozgcloud.eingang.common.vorgang.VorgangNummerSupplier;
import de.ozgcloud.eingang.semantik.enginebased.FilesMapperHelper;
import de.ozgcloud.xta.client.model.XtaMessageMetaData;

@Mapper(imports = { FilesMapperHelper.class, XtaMapperHelper.class })
interface XtaMessageMapper {
	int VORGANG_NUMMER_SUFFIX_LENGTH = 4;

	@Mapping(target = "antragsteller", ignore = true)
	@Mapping(target = "formData", ignore = true)
	@Mapping(target = "id", ignore = true)
	@Mapping(target = "zustaendigeStelle", ignore = true)
	@Mapping(target = "zustaendigeStelles", ignore = true)
	@Mapping(target = "header", source = "metaData")
	@Mapping(target = "numberOfAttachments", expression = "java(FilesMapperHelper.countAttachedFiles(representationsAttachmentsPair.attachments()))")
	@Mapping(target = "numberOfRepresentations", dependsOn = "representations", expression = "java(representationsAttachmentsPair.representations().size())")
	@Mapping(target = "representation", ignore = true)
	@Mapping(target = "attachment", ignore = true)
	@Mapping(target = "control.metaData", source = "metaData")
	FormData toFormData(RepresentationsAttachmentsPair representationsAttachmentsPair, XtaMessageMetaData metaData,
			@Context VorgangNummerSupplier vorgangNummerSupplier);

	@Mapping(target = "formId", source = "messageTypeCode")
	@Mapping(target = "requestId", source = "messageId")
	@Mapping(target = "vorgangNummer", expression = "java(vorgangNummerSupplier.get(VORGANG_NUMMER_SUFFIX_LENGTH))")
	@Mapping(target = "serviceKonto", ignore = true)
	@Mapping(target = "createdAt", expression = "java(XtaMapperHelper.getCreatedAt(metaData))")
	@Mapping(target = "sender", constant = "XTA")
	@Mapping(target = "channel", constant = "XTA")
	@Mapping(target = "formName", ignore = true)
	@Mapping(target = "formEngineName", expression = "java(XtaMapperHelper.getFormEngineName(metaData))")
	FormHeader formHeaderFromMetaData(XtaMessageMetaData metaData, @Context VorgangNummerSupplier vorgangNummerSupplier);

	@Mapping(target = "messageTypeListVersion", ignore = true)
	@Mapping(target = "metaDataFile", ignore = true)
	@Mapping(target = "service", source = "service")
	@Mapping(target = "origin", source = "deliveryAttributesOrigin")
	@Mapping(target = "delivery", source = "deliveryAttributesDelivery")
	@Mapping(target = "messageId", source = "messageId")
	@Mapping(target = "messageType", source = "messageTypeCode")
	@Mapping(target = "xtaIdentifier", source = "readerIdentifier.value")
	XtaFormMetaData formMetaDataFromMetaData(XtaMessageMetaData metaData);

	default XtaMessageId fromString(String id) {
		return XtaMessageId.from(id);
	}

	default Optional<FormMetaData> mapMetaData(XtaMessageMetaData value) {
		return Optional.ofNullable(formMetaDataFromMetaData(value));
	}

}
