/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta.zip;

import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;

public class LimitedInputStream extends FilterInputStream {
	static final String LIMITED_EXCEEDED_MESSAGE = "Read limit exceeded";

	private final long maxSize;
	long bytesRead;

	public LimitedInputStream(InputStream in, long maxSize) {
		super(in);
		this.maxSize = maxSize;
		this.bytesRead = 0;
	}

	@Override
	public int read() throws IOException {
		var byteValue = super.read();
		if (byteValue != -1) {
			updateAndVerifyReadLimit(1);
		}
		return byteValue;
	}

	@Override
	public int read(byte[] b, int off, int len) throws IOException {
		return updateAndVerifyReadLimit(super.read(b, off, len));
	}

	private int updateAndVerifyReadLimit(int newBytesRead) throws IOException {
		if (newBytesRead != -1) {
			bytesRead += newBytesRead;
			if (bytesRead > maxSize) {
				throw new IOException(LIMITED_EXCEEDED_MESSAGE);
			}
		}
		return newBytesRead;
	}
}
