/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xdomea;

import java.util.UUID;
import java.util.stream.Stream;

import de.ozgcloud.eingang.common.formdata.IncomingFileGroup;
import de.ozgcloud.eingang.common.formdata.IncomingFileTestFactory;

public class XdomeaMessageDataTestFactory {
	public static final String XDOMEA_XML_NAME = "xdomea.xml";
	public static final String REPR_XML_NAME = "repr.xml";
	public static final String REPR_PDF_NAME = "repr.pdf";
	public static final String ATTATCHMENT_XML_NAME = "att.xml";
	public static final String ATTATCHMENT_PNG_NAME = "att.png";
	public static final String ATTATCHMENT_PDF_NAME = "att.pdf";


	public static XdomeaMessageData create(boolean useUuidPrefix) {
		return createBuilder(useUuidPrefix).build();
	}

	public static XdomeaMessageData.XdomeaMessageDataBuilder createBuilder(boolean useUuidPrefix) {
		var incomingFiles = Stream.of(
						XDOMEA_XML_NAME,
						REPR_XML_NAME,
						REPR_PDF_NAME,
						ATTATCHMENT_XML_NAME,
						ATTATCHMENT_PNG_NAME,
						ATTATCHMENT_PDF_NAME
				)
				.map(name -> useUuidPrefix ? withUUIDPrefix(name) : name)
				.map(name -> IncomingFileTestFactory.createBuilder().name(name).build())
				.toList();

		return XdomeaMessageData.builder()
				.metadataFile(incomingFiles.getFirst())
				.representations(incomingFiles.subList(1, 3))
				.attachments(incomingFiles.subList(3, 6).stream()
						.map(incomingFile -> IncomingFileGroup.builder()
								.name("group-name")
								.file(incomingFile)
								.build())
						.toList()
				);
	}

	private static String withUUIDPrefix(String name) {
		return UUID.randomUUID() + "_" + name;
	}

}
