/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import java.io.File;
import java.io.InputStream;
import java.math.BigInteger;
import java.nio.charset.StandardCharsets;

import jakarta.activation.DataHandler;
import jakarta.activation.DataSource;
import jakarta.activation.FileDataSource;
import lombok.SneakyThrows;
import org.apache.commons.io.FileUtils;

import de.ozgcloud.xta.client.model.XtaFile;

class XtaFileTestFactory {

	static final String NAME = "Test_File";
	static final String CONTENT = "slkafj3jifsdasx";
	static final String ZIP_CONTENT_TYPE = "application/zip";

	static XtaFile create() {
		return createBuilder().build();
	}

	static XtaFile.XtaFileBuilder createBuilder() {
		return XtaFile.builder()
				.name(NAME)
				.contentType(ZIP_CONTENT_TYPE)
				.content(createData());
	}

	@SneakyThrows
	private static DataHandler createData() {
		File tFile = File.createTempFile("test", ".zip");
		tFile.deleteOnExit();
		FileUtils.write(tFile, CONTENT, StandardCharsets.UTF_8);
		DataSource fds = new FileDataSource(tFile);
		return new DataHandler(fds);
	}

	@SneakyThrows
	static XtaFile withFileContent(InputStream stream, String fileName) {
		File tFile = File.createTempFile(fileName, ".zip");
		tFile.deleteOnExit();
		FileUtils.copyInputStreamToFile(stream, tFile);
		DataSource fds = new FileDataSource(tFile);
		DataHandler data = new DataHandler(fds);
		return createBuilder()
				.name(fileName)
				.size(BigInteger.valueOf(tFile.length()))
				.content(data)
				.build();
	}
}
