/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta;

import static de.ozgcloud.eingang.xta.XtaService.FIM_MESSAGE_TYPE_PREFIX;
import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Spy;

class XtaServiceConfigurationTest {

	XtaProperties properties = XtaPropertiesTestFactory.create();

	@Spy
	XtaServiceConfiguration configuration = new XtaServiceConfiguration(properties);

	@Test
	void testBuildServerAddressUri() {
		assertThat(properties.getServer().getAddress()).isEqualTo(XtaPropertiesTestFactory.SERVER_ADDRESS);

		String serverBaseUrl = configuration.getBaseUrl();

		assertThat(serverBaseUrl).isEqualTo("https://xta-adapter-port-forward-service.ssh-port-forward.svc.cluster.local/MB_XTA-WS/XTA210");
	}

	@Nested
	class TestIsSupportedMessageType {

		private static final String MESSAGE_TYPE_OTHER = "MESSAGE_TYPE_OTHER";

		@Test
		void shouldAcceptGeschaeftsgang() {
			var geschaeftsgangMetaData = XtaMessageMetaDataTestFactory.create();

			assertThat(configuration.isSupportedMessageType(geschaeftsgangMetaData)).isTrue();
		}

		@Test
		void shouldAcceptFIM() {
			var fimMetaData = XtaMessageMetaDataTestFactory.createBuilder()
					.messageTypeCode(FIM_MESSAGE_TYPE_PREFIX + "34355")
					.build();

			assertThat(configuration.isSupportedMessageType(fimMetaData)).isTrue();
		}

		@Test
		void shouldNotAcceptOtherMessageType() {
			var metaDataDFoerder = XtaMessageMetaDataTestFactory.createBuilder()
					.messageTypeCode(MESSAGE_TYPE_OTHER).build();

			assertThat(configuration.isSupportedMessageType(metaDataDFoerder)).isFalse();
		}
	}
}
