/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.xta.zip;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.io.InputStream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;

import de.ozgcloud.eingang.common.errorhandling.TechnicalException;
import lombok.SneakyThrows;

class ReadableZipEntryTest {

	@Mock
	ZipEntry zipEntry;

	@Mock
	ZipFile zipFile;

	private ReadableZipEntry readableZipEntry;

	@BeforeEach
	void mock() {
		readableZipEntry = ReadableZipEntry.builder()
				.zipEntry(zipEntry)
				.parentZip(zipFile)
				.build();

	}

	@DisplayName("get input stream")
	@Nested
	class TestGetInputStream {
		@Mock
		private InputStream inputStream;

		@SneakyThrows
		@DisplayName("should return input stream")
		@Test
		void shouldReturnInputStream() {
			when(zipFile.getInputStream(zipEntry)).thenReturn(inputStream);

			var inputStreamResult = readableZipEntry.getInputStream();

			assertThat(inputStreamResult).isEqualTo(inputStream);
		}
	}

	@DisplayName("get positive size")
	@Nested
	class TestGetPositiveSize {
		@DisplayName("should return size")
		@Test
		void shouldReturnSize() {
			var size = 123L;
			when(zipEntry.getSize()).thenReturn(size);

			var sizeResult = readableZipEntry.getPositiveSize();

			assertThat(sizeResult).isEqualTo(size);
		}

		@DisplayName("should throw if size is negative")
		@Test
		void shouldThrowIfSizeIsNegative() {
			var size = -1L;
			when(zipEntry.getSize()).thenReturn(size);

			assertThatThrownBy(() -> readableZipEntry.getPositiveSize()).isInstanceOf(TechnicalException.class);
		}

	}
}
